pub mod bias;
mod bias_and_genes;
pub mod connection_type;
pub mod gene;
pub mod mutation_probabilities;
mod serialization;
mod topology_struct;

pub use topology_struct::*;
